Networking (raw-byte packets over channels).
Macros
- packet
- Declare a typed packet struct whose fields are automatically encoded/decoded.
Structs
- Packet
Event - A packet received on a channel.
Traits
- Packet
- A typed packet that can be encoded to / decoded from a raw byte buffer.
- Packet
Field - Encode/decode a single field to/from a byte buffer.