pub struct Interop { /* private fields */ }Expand description
Safe wrapper around the runtime’s inter-mod symbol table.
Returned by Registry::interop.
Implementations
Sourceimpl Interop
impl Interop
Sourcepub fn export(&self, symbol: &str, ptr: *const c_void)
pub fn export(&self, symbol: &str, ptr: *const c_void)
Export a function pointer under symbol for the current mod.
The mod’s ID is automatically determined from the manifest (passed
to yog_mod_register by the runtime).
Sourcepub fn import_raw(&self, mod_id: &str, symbol: &str) -> Option<*const c_void>
pub fn import_raw(&self, mod_id: &str, symbol: &str) -> Option<*const c_void>
Import a function pointer exported by mod_id under symbol.
Use the qualified form "mod_id:symbol":
ⓘ
let ptr: *const c_void = interop.import("yog-pipes:register_pipe").unwrap();Returns None if the symbol has not been exported (yet).