pub struct SlotLayout {
pub x: f32,
pub y: f32,
}Expand description
Pixel position of a single slot in vanilla GUI coordinate space (the same space vanilla screens use: origin at the panel’s top-left corner, one vanilla slot = 18×18px).
Fields
x: f32y: f32Trait Implementations
Sourceimpl Clone for SlotLayout
impl Clone for SlotLayout
Sourcefn clone(&self) -> SlotLayout
fn clone(&self) -> SlotLayout
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SlotLayout
Sourceimpl Debug for SlotLayout
impl Debug for SlotLayout
Sourceimpl<'de> Deserialize<'de> for SlotLayout
impl<'de> Deserialize<'de> for SlotLayout
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<SlotLayout, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<SlotLayout, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for SlotLayout
impl PartialEq for SlotLayout
Sourcefn eq(&self, other: &SlotLayout) -> bool
fn eq(&self, other: &SlotLayout) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SlotLayout