pub fn set_focus(node: &mut LayoutNode, focused_id: Option<&str>)Expand description
Walk tree and set focused = true on the node whose id matches, false on all others.
pub fn set_focus(node: &mut LayoutNode, focused_id: Option<&str>)Walk tree and set focused = true on the node whose id matches, false on all others.