pub struct BookViewState {
pub cat: usize,
pub entry: usize,
pub page: usize,
pub at_home: bool,
pub list_spread: usize,
}Fields
cat: usizeentry: usizepage: usizeat_home: boollist_spread: usizeImplementations
Sourceimpl BookViewState
impl BookViewState
Sourcepub fn handle(&mut self, ev: &str, book: &Book) -> bool
pub fn handle(&mut self, ev: &str, book: &Book) -> bool
Handle a navigation event string. Returns true if state changed.
Sourcepub fn entries_in_cat<'b>(&self, book: &'b Book) -> Vec<&'b BookEntry>
pub fn entries_in_cat<'b>(&self, book: &'b Book) -> Vec<&'b BookEntry>
All entries in the current category, unfiltered.
Sourcepub fn list_spread_count(&self, book: &Book) -> usize
pub fn list_spread_count(&self, book: &Book) -> usize
How many list spreads the current category needs.
Sourcepub fn list_spread_start(&self) -> usize
pub fn list_spread_start(&self) -> usize
Absolute index of the first entry on the current list spread.
Sourcepub fn entries_visible<'b>(&self, book: &'b Book) -> Vec<&'b BookEntry>
pub fn entries_visible<'b>(&self, book: &'b Book) -> Vec<&'b BookEntry>
The slice of entries visible on the current list spread.
pub fn current_entry<'b>(&self, book: &'b Book) -> Option<&'b BookEntry>
pub fn page_count(&self, book: &Book) -> usize