Module network

Module network 

Networking (raw-byte packets over channels).

Macros

packet
Declare a typed packet struct whose fields are automatically encoded/decoded.

Structs

PacketEvent
A packet received on a channel.

Traits

Packet
A typed packet that can be encoded to / decoded from a raw byte buffer.
PacketField
Encode/decode a single field to/from a byte buffer.