pub struct ItemPickupEvent {
pub player_name: String,
pub player_uuid: String,
pub item_id: String,
pub item_count: u32,
pub entity_uuid: String,
}Expand description
Fired when a player picks up an item entity.
Pre— returnfalseto prevent the pickup.Post— item was successfully picked up.
Fields
player_name: Stringplayer_uuid: Stringitem_id: StringRegistry id of the item, e.g. "minecraft:diamond".
item_count: u32entity_uuid: StringUUID of the item entity that was picked up.