pub struct PlayerMoveEvent {
pub player_name: String,
pub player_uuid: String,
pub x: f64,
pub y: f64,
pub z: f64,
pub yaw: f32,
pub pitch: f32,
}Expand description
Fired every time a player sends a movement packet (very high frequency).
Post-phase only. The fields reflect the new position the client claims.
Fields
player_name: Stringplayer_uuid: Stringx: f64y: f64z: f64yaw: f32pitch: f32Trait Implementations
Sourceimpl Clone for PlayerMoveEvent
impl Clone for PlayerMoveEvent
Sourcefn clone(&self) -> PlayerMoveEvent
fn clone(&self) -> PlayerMoveEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for PlayerMoveEvent
impl RefUnwindSafe for PlayerMoveEvent
impl Send for PlayerMoveEvent
impl Sync for PlayerMoveEvent
impl Unpin for PlayerMoveEvent
impl UnsafeUnpin for PlayerMoveEvent
impl UnwindSafe for PlayerMoveEvent