Module text

Module text 

Text wrapping utilities shared by layout (measuring) and render (drawing).

Constants

CHAR_W
Approximate pixel width per character at font_scale=1.0 in Minecraft’s default font.
LINE_GAP
Gap between wrapped lines.
LINE_H
Line height at font_scale=1.0.

Functions

line_count
Number of lines that text wraps to, at the given scale in max_w pixels.
text_height
Total height (px) of wrapped text.
wrap_text
Break text into lines that fit within max_w pixels at font_scale. Words that are longer than one line get hard-broken at the character boundary.